
## References

<a name="boule"></a>  
+ C. Boule, K. Andrews, A. Penfield, I. Puckette, K. A. Goodale and 
S. A. Harfenist. **Determining Binary Stellar Orbits Using Kepplers Equation**.
Journal of Double Star Observations, Vol 13, p 189. 2017.<br>

<a name="bischop"></a>  
+ C.M. Bishop. **Pattern Recognition and Machine Learning.**
Springer Science. 2006.<br>

<a name="gregory"></a>  
+ P.C. Gregory. **Bayesian Logical Data Analysis for the Physical Sciences.**
Cambridge University Press. 2005.<br>

<a name="jaynes"></a>  
+ E.T. Jaynes. **Probability Theory.**
Cambridge University Press. 2003.<br>

<a name="kester1"></a>  
+ Do Kester. **Straight Lines.**
Maximum Entropy and Bayesian Methods. Eds: Von der Linden, W., et al.
Garching, Kluwer Academic Publishers, pp. 179-188, 1999.<br>

<a name="kester2"></a>  
+ Do Kester. **A Software Package for Parameter Estimation and Model Comparison.**
In: Bayesian Inference and Maximum Entropy Methods in Science and Engineering
Eds: R. Fischer et al.
Garching, 2004, AIP Conference Proceedings 735 2004, p. 379.<br>

<a name="kester3"></a>  
+ Do Kester, Douwe Beintema and Dieter Lutz. 
**SWS Fringes and Models**
ESA SP-481, Vilspa, pp. 375-378. 2009.<br>

<a name="kester4"></a>  
+ Do Kester and Romke Bontekoe.
**Darwinian Model Building.**
Bayesian Inference and Maximum Entropy Methods in Science and Engineering.
Eds: Ali-Mohammad Djafari et al. Chamonix. 
AIP Conference Proceedings 1305, p.49. 2010.<br>

<a name="kester5"></a>  
+ Do Kester.
**The Ball is Round.**
Bayesian Inference and Maximum Entropy Methods in Science and Engineering.
Eds: Ali-Mohammad Djafari et al. Chamonix.
AIP Conference Proceedings 1305. p.107. 2010.<br>

<a name="kester6"></a>  
+ Do Kester, Ian Avruch and David Teyssier. 
**Correction of Electric Standing Waves.** 
in Bayesian Inference and Maximum Entropy Methods in Science and Engineering,
AIP Conf. Proc., 1636, 62. 2014.<br>

<a name="kester7"></a>  
+ Do Kester, Ronan Higgins and David Teyssier.
**Derivation of sideband gain ratio for Herschel/HIFI**
A &amp; A 599 A115. 2017.<br>

<a name="kester8"></a>  
+ Do Kester and Migo Mueller.
**BayesicFitting, a PYTHON toolbox for Bayesian fitting and Evidence Calculation**
Astronomy and Computing, Vol 37, 100503. 2021. doi: 10.1016/j.ascom.2021.100503<br>

<a name="linden"></a>  
+ W. von der Linden, V. Dose, U. Toussaint. 
**Bayesian Probabilty Theory.** 
Cambridge University Press. 2014.<br>

<a name="press"></a>
+ W.H. Press, S.A. Teukolsky, W.T. Vetterling and B.P. Flannery
**Numerical Recipes**,
Cambridge University Press. 1988-2007. <br>

<a name="sivia"></a>
+ D.S. Sivia and J. Skilling. 
**Data Analysis, A Bayesian Tutorial.** 
Oxford University Press. 2006.<br>

